@@ -2,7 +2,7 @@
 from __future__ import absolute_import
 
 # Possible version formats: "3.1.0", "3.1.0a1", "3.1.0a1.dev0"
-__version__ = "3.0.5"
+__version__ = "3.0.6"
 
 try:
     from __builtin__ import basestring
@@ -111,9 +111,15 @@ cclass = ccall = cfunc = _EmptyDecoratorAndManager()
 annotation_typing = returns = wraparound = boundscheck = initializedcheck = \
     nonecheck = embedsignature = cdivision = cdivision_warnings = \
     always_allow_keywords = profile = linetrace = infer_types = \
-    unraisable_tracebacks = freelist = \
+    unraisable_tracebacks = freelist = auto_pickle = cpow = trashcan = \
+    auto_cpdef = c_api_binop_methods = \
+    allow_none_for_extension_args = callspec = show_performance_hints = \
+    cpp_locals = py2_import = iterable_coroutine = remove_unreachable = \
         lambda _: _EmptyDecoratorAndManager()
 
+# Note that fast_getattr is untested and undocumented!
+fast_getattr = lambda _: _EmptyDecoratorAndManager()
+
 exceptval = lambda _=None, check=True: _EmptyDecoratorAndManager()
 
 overflowcheck = lambda _: _EmptyDecoratorAndManager()
@@ -123,10 +129,16 @@ optimize = _Optimization()
 embedsignature.format = overflowcheck.fold = optimize.use_switch = \
     optimize.unpack_method_calls = lambda arg: _EmptyDecoratorAndManager()
 
-final = internal = type_version_tag = no_gc_clear = no_gc = total_ordering = _empty_decorator
+final = internal = type_version_tag = no_gc_clear = no_gc = total_ordering = \
+    ufunc = _empty_decorator
 
 binding = lambda _: _empty_decorator
 
+class warn:
+    undeclared = unreachable = maybe_uninitialized = unused = \
+        unused_arg = unused_result = \
+            lambda _: _EmptyDecoratorAndManager()
+
 
 _cython_inline = None
 def inline(f, *args, **kwds):
